var classtvg_1_1Canvas =
[
    [ "clear", "classtvg_1_1Canvas.html#a99cdb01cd893f4199b521b754d21aefd", null ],
    [ "draw", "classtvg_1_1Canvas.html#aabf9e5a14da3b4bfd5883c2b4459abd0", null ],
    [ "paints", "classtvg_1_1Canvas.html#ace6c268f853a4c144076de89b7bbbe75", null ],
    [ "push", "classtvg_1_1Canvas.html#a82c5ec1c1ba93cf7671642400074201e", null ],
    [ "sync", "classtvg_1_1Canvas.html#adbca600af79f9a0b8e8366e3be7450e9", null ],
    [ "update", "classtvg_1_1Canvas.html#a89ac8a85a8c22723af9fb07c098472b3", null ],
    [ "viewport", "classtvg_1_1Canvas.html#a2172bfc1790cee5dedd9cda7a2caf64e", null ]
];